@@ -16,8 +16,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include <config.h>
-#include <libgnome/libgnome.h>
+#include "config.h"
+
+#include <glib/gi18n.h>
 #include <syslog.h>
 #include <pwd.h>
 #include <grp.h>
@@ -69,9 +70,7 @@ print_cant_auth_errbox (void)
 		    "case.");
 	if (is_capslock) {
 		msg = g_strconcat (basemsg, "  ",
-				   _("Please make sure the "
-				     "Caps Lock key is not "
-				     "enabled."),
+				   _("Caps Lock is on."),
 				   NULL);
 	} else {
 		msg = g_strdup (basemsg);
